@@ -4,13 +4,12 @@ from alibabacloud_credentials.utils import auth_constant as ac
 
 
 class _AutomaticallyRefreshCredentials:
-    def __init__(self, expiration, provider, refresh_fields):
+    def __init__(self, expiration, provider):
         self.expiration = expiration
         self.provider = provider
-        self._REFRESH_FIELDS = refresh_fields
 
     def _with_should_refresh(self):
-        return int(time.mktime(time.localtime())) >= (object.__getattribute__(self, 'expiration') - 180)
+        return int(time.mktime(time.localtime())) >= (self.expiration - 180)
 
     def _get_new_credential(self):
         return self.provider.get_credentials()
@@ -19,11 +18,6 @@ class _AutomaticallyRefreshCredentials:
         if self._with_should_refresh():
             return self._get_new_credential()
 
-    def __getattribute__(self, item):
-        if item in object.__getattribute__(self, '__dict__')['_REFRESH_FIELDS']:
-            self._refresh_credential()
-        return object.__getattribute__(self, item)
-
 
 class AccessKeyCredential:
     """AccessKeyCredential"""
@@ -33,6 +27,12 @@ class AccessKeyCredential:
         self.access_key_secret = access_key_secret
         self.credential_type = ac.ACCESS_KEY
 
+    def get_access_key_id(self):
+        return self.access_key_id
+
+    def get_access_key_secret(self):
+        return self.access_key_secret
+
 
 class BearerTokenCredential:
     """BearerTokenCredential"""
@@ -46,13 +46,7 @@ class EcsRamRoleCredential(_AutomaticallyRefreshCredentials):
     """EcsRamRoleCredential"""
 
     def __init__(self, access_key_id, access_key_secret, security_token, expiration, provider):
-        refresh_fields = (
-            'access_key_id',
-            'access_key_secret',
-            'security_token',
-            'expiration'
-        )
-        super().__init__(expiration, provider, refresh_fields)
+        super().__init__(expiration, provider)
         self.access_key_id = access_key_id
         self.access_key_secret = access_key_secret
         self.security_token = security_token
@@ -66,18 +60,24 @@ class EcsRamRoleCredential(_AutomaticallyRefreshCredentials):
             self.expiration = credential.expiration
             self.security_token = credential.security_token
 
+    def get_access_key_id(self):
+        self._refresh_credential()
+        return self.access_key_id
+
+    def get_access_key_secret(self):
+        self._refresh_credential()
+        return self.access_key_secret
+
+    def get_security_token(self):
+        self._refresh_credential()
+        return self.security_token
+
 
 class RamRoleArnCredential(_AutomaticallyRefreshCredentials):
     """RamRoleArnCredential"""
 
     def __init__(self, access_key_id, access_key_secret, security_token, expiration, provider):
-        refresh_fields = (
-            'access_key_id',
-            'access_key_secret',
-            'security_token',
-            'expiration'
-        )
-        super().__init__(expiration, provider, refresh_fields)
+        super().__init__(expiration, provider)
         self.access_key_id = access_key_id
         self.access_key_secret = access_key_secret
         self.security_token = security_token
@@ -91,15 +91,22 @@ class RamRoleArnCredential(_AutomaticallyRefreshCredentials):
             self.expiration = credential.expiration
             self.security_token = credential.security_token
 
+    def get_access_key_id(self):
+        self._refresh_credential()
+        return self.access_key_id
+
+    def get_access_key_secret(self):
+        self._refresh_credential()
+        return self.access_key_secret
+
+    def get_security_token(self):
+        self._refresh_credential()
+        return self.security_token
+
 
 class RsaKeyPairCredential(_AutomaticallyRefreshCredentials):
     def __init__(self, access_key_id, access_key_secret, expiration, provider):
-        refresh_fields = (
-            'access_key_id',
-            'access_key_secret',
-            'expiration'
-        )
-        super().__init__(expiration, provider, refresh_fields)
+        super().__init__(expiration, provider)
         self.access_key_id = access_key_id
         self.access_key_secret = access_key_secret
         self.credential_type = ac.RSA_KEY_PAIR
@@ -111,6 +118,14 @@ class RsaKeyPairCredential(_AutomaticallyRefreshCredentials):
             self.access_key_secret = credential.access_key_secret
             self.expiration = credential.expiration
 
+    def get_access_key_id(self):
+        self._refresh_credential()
+        return self.access_key_id
+
+    def get_access_key_secret(self):
+        self._refresh_credential()
+        return self.access_key_secret
+
 
 class StsCredential:
     def __init__(self, access_key_id, access_key_secret, security_token):
@@ -118,3 +133,12 @@ class StsCredential:
         self.access_key_secret = access_key_secret
         self.security_token = security_token
         self.credential_type = ac.STS
+
+    def get_access_key_id(self):
+        return self.access_key_id
+
+    def get_access_key_secret(self):
+        return self.access_key_secret
+
+    def get_security_token(self):
+        return self.security_token
